>From 95ba977e7d2ace2dc51f224ed30896f68fd62e3b Mon Sep 17 00:00:00 2001
From: Tadas Slotkus <devtadas@gmail.com>
Date: Fri, 19 Aug 2011 15:35:28 +0300
Subject: [carFl mem 32/65] Globalisation pass 1: w39.c

This commit breaks builds until "Globalistation pass 1: fixes".

It does nothing more, just passes globals structure across function
calls.

Signed-off-by: Tadas Slotkus <devtadas@gmail.com>
---
 w39.c |  102 ++++++++++++++++++++++++++++++++--------------------------------
 1 files changed, 51 insertions(+), 51 deletions(-)

diff --git a/w39.c b/w39.c
index 920a43f..4b3af1f 100644
--- a/w39.c
+++ b/w39.c
@@ -22,12 +22,12 @@
 #include "flash.h"
 #include "chipdrivers.h"
 
-static int printlock_w39_fwh_block(struct flashchip *flash, int offset)
+static int printlock_w39_fwh_block(globals *g, struct flashchip *flash, int offset)
 {
 	chipaddr wrprotect = flash->virtual_registers + offset + 2;
 	uint8_t locking;
 
-	locking = chip_readb(wrprotect);
+	locking = chip_readb(g, wrprotect);
 	msg_cdbg("Lock status of block at 0x%08x is ", offset);
 	switch (locking & 0x7) {
 	case 0:
@@ -60,12 +60,12 @@ static int printlock_w39_fwh_block(struct flashchip *flash, int offset)
 	return (locking & ((1 << 2) | (1 << 0))) ? -1 : 0;
 }
 
-static int unlock_w39_fwh_block(struct flashchip *flash, int offset)
+static int unlock_w39_fwh_block(globals *g, struct flashchip *flash, int offset)
 {
 	chipaddr wrprotect = flash->virtual_registers + offset + 2;
 	uint8_t locking;
 
-	locking = chip_readb(wrprotect);
+	locking = chip_readb(g, wrprotect);
 	/* Read or write lock present? */
 	if (locking & ((1 << 2) | (1 << 0))) {
 		/* Lockdown active? */
@@ -74,32 +74,32 @@ static int unlock_w39_fwh_block(struct flashchip *flash, int offset)
 			return -1;
 		} else {
 			msg_cdbg("Unlocking block at 0x%08x\n", offset);
-			chip_writeb(0, wrprotect);
+			chip_writeb(g, 0, wrprotect);
 		}
 	}
 
 	return 0;
 }
 
-static uint8_t w39_idmode_readb(struct flashchip *flash, int offset)
+static uint8_t w39_idmode_readb(globals *g, struct flashchip *flash, int offset)
 {
 	chipaddr bios = flash->virtual_memory;
 	uint8_t val;
 
 	/* Product Identification Entry */
-	chip_writeb(0xAA, bios + 0x5555);
-	chip_writeb(0x55, bios + 0x2AAA);
-	chip_writeb(0x90, bios + 0x5555);
-	programmer_delay(10);
+	chip_writeb(g, 0xAA, bios + 0x5555);
+	chip_writeb(g, 0x55, bios + 0x2AAA);
+	chip_writeb(g, 0x90, bios + 0x5555);
+	programmer_delay(g, 10);
 
 	/* Read something, maybe hardware lock bits */
-	val = chip_readb(bios + offset);
+	val = chip_readb(g, bios + offset);
 
 	/* Product Identification Exit */
-	chip_writeb(0xAA, bios + 0x5555);
-	chip_writeb(0x55, bios + 0x2AAA);
-	chip_writeb(0xF0, bios + 0x5555);
-	programmer_delay(10);
+	chip_writeb(g, 0xAA, bios + 0x5555);
+	chip_writeb(g, 0x55, bios + 0x2AAA);
+	chip_writeb(g, 0xF0, bios + 0x5555);
+	programmer_delay(g, 10);
 
 	return val;
 }
@@ -128,56 +128,56 @@ static int printlock_w39_bootblock_64k16k(uint8_t lock)
 	return 0;
 }
 
-static int printlock_w39_common(struct flashchip *flash, int offset)
+static int printlock_w39_common(globals *g, struct flashchip *flash, int offset)
 {
 	uint8_t lock;
 
-	lock = w39_idmode_readb(flash, offset);
+	lock = w39_idmode_readb(g, flash, offset);
 	msg_cdbg("Lockout bits:\n");
 	return printlock_w39_tblwp(lock);
 }
 
-static int printlock_w39_fwh(struct flashchip *flash)
+static int printlock_w39_fwh(globals *g, struct flashchip *flash)
 {
 	int i, total_size = flash->total_size * 1024;
 	int ret = 0;
 	
 	/* Print lock status of the complete chip */
 	for (i = 0; i < total_size; i += flash->page_size)
-		ret |= printlock_w39_fwh_block(flash, i);
+		ret |= printlock_w39_fwh_block(g, flash, i);
 
 	return ret;
 }
 
-static int unlock_w39_fwh(struct flashchip *flash)
+static int unlock_w39_fwh(globals *g, struct flashchip *flash)
 {
 	int i, total_size = flash->total_size * 1024;
 	
 	/* Unlock the complete chip */
 	for (i = 0; i < total_size; i += flash->page_size)
-		if (unlock_w39_fwh_block(flash, i))
+		if (unlock_w39_fwh_block(g, flash, i))
 			return -1;
 
 	return 0;
 }
 
-int printlock_w39l040(struct flashchip * flash)
+int printlock_w39l040(globals *g, struct flashchip * flash)
 {
 	uint8_t lock;
 	int ret;
 
-	lock = w39_idmode_readb(flash, 0x00002);
+	lock = w39_idmode_readb(g, flash, 0x00002);
 	msg_cdbg("Bottom boot block:\n");
 	ret = printlock_w39_bootblock_64k16k(lock);
 
-	lock = w39_idmode_readb(flash, 0x7fff2);
+	lock = w39_idmode_readb(g, flash, 0x7fff2);
 	msg_cdbg("Top boot block:\n");
 	ret |= printlock_w39_bootblock_64k16k(lock);
 
 	return ret;
 }
 
-int printlock_w39v040a(struct flashchip *flash)
+int printlock_w39v040a(globals *g, struct flashchip *flash)
 {
 	uint8_t lock;
 	int ret = 0;
@@ -186,7 +186,7 @@ int printlock_w39v040a(struct flashchip *flash)
 	 * location: 0x00002 and 0x7fff2 are both mentioned. Pick the one
 	 * which is similar to the other chips of the same family.
 	 */
-	lock = w39_idmode_readb(flash, 0x7fff2);
+	lock = w39_idmode_readb(g, flash, 0x7fff2);
 	msg_cdbg("Lockout bits:\n");
 
 	ret = printlock_w39_tblwp(lock);
@@ -195,64 +195,64 @@ int printlock_w39v040a(struct flashchip *flash)
 	return ret;
 }
 
-int printlock_w39v040b(struct flashchip *flash)
+int printlock_w39v040b(globals *g, struct flashchip *flash)
 {
-	return printlock_w39_common(flash, 0x7fff2);
+	return printlock_w39_common(g, flash, 0x7fff2);
 }
 
-int printlock_w39v040c(struct flashchip *flash)
+int printlock_w39v040c(globals *g, struct flashchip *flash)
 {
 	/* Typo in the datasheet? The other chips use 0x7fff2. */
-	return printlock_w39_common(flash, 0xfff2);
+	return printlock_w39_common(g, flash, 0xfff2);
 }
 
-int printlock_w39v040fa(struct flashchip *flash)
+int printlock_w39v040fa(globals *g, struct flashchip *flash)
 {
 	int ret = 0;
 
-	ret = printlock_w39v040a(flash);
-	ret |= printlock_w39_fwh(flash);
+	ret = printlock_w39v040a(g, flash);
+	ret |= printlock_w39_fwh(g, flash);
 
 	return ret;
 }
 
-int printlock_w39v040fb(struct flashchip *flash)
+int printlock_w39v040fb(globals *g, struct flashchip *flash)
 {
 	int ret = 0;
 
-	ret = printlock_w39v040b(flash);
-	ret |= printlock_w39_fwh(flash);
+	ret = printlock_w39v040b(g, flash);
+	ret |= printlock_w39_fwh(g, flash);
 
 	return ret;
 }
 
-int printlock_w39v040fc(struct flashchip *flash)
+int printlock_w39v040fc(globals *g, struct flashchip *flash)
 {
 	int ret = 0;
 
 	/* W39V040C and W39V040FC use different WP/TBL offsets. */
-	ret = printlock_w39_common(flash, 0x7fff2);
-	ret |= printlock_w39_fwh(flash);
+	ret = printlock_w39_common(g, flash, 0x7fff2);
+	ret |= printlock_w39_fwh(g, flash);
 
 	return ret;
 }
 
-int printlock_w39v080a(struct flashchip *flash)
+int printlock_w39v080a(globals *g, struct flashchip *flash)
 {
-	return printlock_w39_common(flash, 0xffff2);
+	return printlock_w39_common(g, flash, 0xffff2);
 }
 
-int printlock_w39v080fa(struct flashchip *flash)
+int printlock_w39v080fa(globals *g, struct flashchip *flash)
 {
 	int ret = 0;
 
-	ret = printlock_w39v080a(flash);
-	ret |= printlock_w39_fwh(flash);
+	ret = printlock_w39v080a(g, flash);
+	ret |= printlock_w39_fwh(g, flash);
 
 	return ret;
 }
 
-int printlock_w39v080fa_dual(struct flashchip *flash)
+int printlock_w39v080fa_dual(globals *g, struct flashchip *flash)
 {
 	msg_cinfo("Block locking for W39V080FA in dual mode is "
 		  "undocumented.\n");
@@ -260,21 +260,21 @@ int printlock_w39v080fa_dual(struct flashchip *flash)
 	return -1;
 }
 
-int unlock_w39v040fb(struct flashchip *flash)
+int unlock_w39v040fb(globals *g, struct flashchip *flash)
 {
-	if (unlock_w39_fwh(flash))
+	if (unlock_w39_fwh(g, flash))
 		return -1;
-	if (printlock_w39_common(flash, 0x7fff2))
+	if (printlock_w39_common(g, flash, 0x7fff2))
 		return -1;
 
 	return 0;
 }
 
-int unlock_w39v080fa(struct flashchip *flash)
+int unlock_w39v080fa(globals *g, struct flashchip *flash)
 {
-	if (unlock_w39_fwh(flash))
+	if (unlock_w39_fwh(g, flash))
 		return -1;
-	if (printlock_w39_common(flash, 0xffff2))
+	if (printlock_w39_common(g, flash, 0xffff2))
 		return -1;
 
 	return 0;
-- 
1.7.6

